@@ -46,7 +46,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <QJsonObject>
 
 // KF
-#include <kxmlgui_version.h>
 #include <KActionCategory>
 #include <KActionCollection>
 #include <KDirLister>
@@ -67,6 +66,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <KUrlComboBox>
 #include <KUrlNavigator>
 #include <KXMLGUIFactory>
+#include <kwidgetsaddons_version.h>
+#include <kxmlgui_version.h>
 #ifndef GWENVIEW_SEMANTICINFO_BACKEND_NONE
 #include "lib/semanticinfo/semanticinfodirmodel.h"
 #endif
@@ -76,10 +77,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #endif
 
 // Local
-#include "gwenview_app_debug.h"
 #include "alignwithsidebarwidgetaction.h"
 #include "configdialog.h"
-#include "dialogguard.h"
 #include "documentinfoprovider.h"
 #include "fileopscontextmanageritem.h"
 #include "folderviewcontextmanageritem.h"
@@ -386,9 +385,9 @@ struct MainWindow::Private {
         file->addAction(KStandardAction::PrintPreview, q, SLOT(printPreview()));
         file->addAction(KStandardAction::Quit, qApp, SLOT(closeAllWindows()));
 
-        QAction *action = file->addAction("reload", q, SLOT(reload()));
+        QAction *action = file->addAction(QStringLiteral("reload"), q, SLOT(reload()));
         action->setText(i18nc("@action reload the currently viewed image", "Reload"));
-        action->setIcon(QIcon::fromTheme("view-refresh"));
+        action->setIcon(QIcon::fromTheme(QStringLiteral("view-refresh")));
         actionCollection->setDefaultShortcuts(action, KStandardShortcut::reload());
 
         QAction *replaceLocationAction = actionCollection->addAction(QStringLiteral("replace_location"));
@@ -396,18 +395,18 @@ struct MainWindow::Private {
         actionCollection->setDefaultShortcut(replaceLocationAction, Qt::CTRL | Qt::Key_L);
         connect(replaceLocationAction, &QAction::triggered, q, &MainWindow::replaceLocation);
 
-        mBrowseAction = view->addAction("browse");
+        mBrowseAction = view->addAction(QStringLiteral("browse"));
         mBrowseAction->setText(i18nc("@action:intoolbar Switch to file list", "Browse"));
         mBrowseAction->setToolTip(i18nc("@info:tooltip", "Browse folders for images"));
         mBrowseAction->setCheckable(true);
-        mBrowseAction->setIcon(QIcon::fromTheme("view-list-icons"));
+        mBrowseAction->setIcon(QIcon::fromTheme(QStringLiteral("view-list-icons")));
         actionCollection->setDefaultShortcut(mBrowseAction, Qt::Key_Escape);
         connect(mViewMainPage, &ViewMainPage::goToBrowseModeRequested, mBrowseAction, &QAction::trigger);
 
-        mViewAction = view->addAction("view");
+        mViewAction = view->addAction(QStringLiteral("view"));
         mViewAction->setText(i18nc("@action:intoolbar Switch to image view", "View"));
         mViewAction->setToolTip(i18nc("@info:tooltip", "View selected images"));
-        mViewAction->setIcon(QIcon::fromTheme("view-preview"));
+        mViewAction->setIcon(QIcon::fromTheme(QStringLiteral("view-preview")));
         mViewAction->setCheckable(true);
 
         mViewModeActionGroup = new QActionGroup(q);
@@ -424,7 +423,7 @@ struct MainWindow::Private {
         connect(mViewMainPage, &ViewMainPage::toggleFullScreenRequested, mFullScreenAction, &QAction::trigger);
 
         QAction *leaveFullScreenAction = view->addAction("leave_fullscreen", q, SLOT(leaveFullScreen()));
-        leaveFullScreenAction->setIcon(QIcon::fromTheme("view-restore"));
+        leaveFullScreenAction->setIcon(QIcon::fromTheme(QStringLiteral("view-restore")));
         leaveFullScreenAction->setText(i18nc("@action", "Exit Full Screen"));
 
         mGoToPreviousAction = view->addAction("go_previous", q, SLOT(goToPrevious()));
@@ -434,23 +433,23 @@ struct MainWindow::Private {
         mGoToPreviousAction->setToolTip(i18nc("@info:tooltip", "Go to previous image"));
         installDisabledActionShortcutMonitor(mGoToPreviousAction, SLOT(showFirstDocumentReached()));
 
-        mGoToNextAction = view->addAction("go_next", q, SLOT(goToNext()));
+        mGoToNextAction = view->addAction(QStringLiteral("go_next"), q, SLOT(goToNext()));
         mGoToNextAction->setPriority(QAction::LowPriority);
         mGoToNextAction->setIcon(QIcon::fromTheme(QGuiApplication::layoutDirection() == Qt::LeftToRight ? "go-next" : "go-next-symbolic-rtl"));
         mGoToNextAction->setText(i18nc("@action Go to next image", "Next"));
         mGoToNextAction->setToolTip(i18nc("@info:tooltip", "Go to next image"));
         installDisabledActionShortcutMonitor(mGoToNextAction, SLOT(showLastDocumentReached()));
 
-        mGoToFirstAction = view->addAction("go_first", q, SLOT(goToFirst()));
+        mGoToFirstAction = view->addAction(QStringLiteral("go_first"), q, SLOT(goToFirst()));
         mGoToFirstAction->setPriority(QAction::LowPriority);
-        mGoToFirstAction->setIcon(QIcon::fromTheme("go-first-view"));
+        mGoToFirstAction->setIcon(QIcon::fromTheme(QStringLiteral("go-first-view")));
         mGoToFirstAction->setText(i18nc("@action Go to first image", "First"));
         mGoToFirstAction->setToolTip(i18nc("@info:tooltip", "Go to first image"));
         actionCollection->setDefaultShortcut(mGoToFirstAction, Qt::Key_Home);
 
-        mGoToLastAction = view->addAction("go_last", q, SLOT(goToLast()));
+        mGoToLastAction = view->addAction(QStringLiteral("go_last"), q, SLOT(goToLast()));
         mGoToLastAction->setPriority(QAction::LowPriority);
-        mGoToLastAction->setIcon(QIcon::fromTheme("go-last-view"));
+        mGoToLastAction->setIcon(QIcon::fromTheme(QStringLiteral("go-last-view")));
         mGoToLastAction->setText(i18nc("@action Go to last image", "Last"));
         mGoToLastAction->setToolTip(i18nc("@info:tooltip", "Go to last image"));
         actionCollection->setDefaultShortcut(mGoToLastAction, Qt::Key_End);
@@ -461,20 +460,20 @@ struct MainWindow::Private {
 
         action = view->addAction("go_start_page", q, SLOT(showStartMainPage()));
         action->setPriority(QAction::LowPriority);
-        action->setIcon(QIcon::fromTheme("go-home"));
+        action->setIcon(QIcon::fromTheme(QStringLiteral("go-home")));
         action->setText(i18nc("@action", "Start Page"));
         action->setToolTip(i18nc("@info:tooltip", "Open the start page"));
         actionCollection->setDefaultShortcuts(action, KStandardShortcut::home());
 
-        mToggleSideBarAction = view->add<KToggleAction>("toggle_sidebar");
+        mToggleSideBarAction = view->add<KToggleAction>(QStringLiteral("toggle_sidebar"));
         connect(mToggleSideBarAction, &KToggleAction::triggered, q, &MainWindow::toggleSideBar);
-        mToggleSideBarAction->setIcon(QIcon::fromTheme("view-sidetree"));
+        mToggleSideBarAction->setIcon(QIcon::fromTheme(QStringLiteral("view-sidetree")));
         actionCollection->setDefaultShortcut(mToggleSideBarAction, Qt::Key_F4);
         mToggleSideBarAction->setText(i18nc("@action", "Sidebar"));
         connect(mBrowseMainPage->toggleSideBarButton(), &QAbstractButton::clicked, mToggleSideBarAction, &QAction::trigger);
         connect(mViewMainPage->toggleSideBarButton(), &QAbstractButton::clicked, mToggleSideBarAction, &QAction::trigger);
 
-        mToggleOperationsSideBarAction = view->add<KToggleAction>("toggle_operations_sidebar");
+        mToggleOperationsSideBarAction = view->add<KToggleAction>(QStringLiteral("toggle_operations_sidebar"));
         mToggleOperationsSideBarAction->setText(i18nc("@action opens crop, rename, etc.", "Show Editing Tools"));
         mToggleOperationsSideBarAction->setIcon(QIcon::fromTheme(QStringLiteral("edit-image"), QIcon::fromTheme(QStringLiteral("document-edit"))));
         connect(mToggleOperationsSideBarAction, &KToggleAction::triggered, q, &MainWindow::toggleOperationsSideBar);
@@ -482,7 +481,7 @@ struct MainWindow::Private {
             mToggleOperationsSideBarAction->setChecked(mSideBar->isVisible() && mSideBar->currentPage() == QLatin1String("operations"));
         });
 
-        mToggleSlideShowAction = view->addAction("toggle_slideshow", q, SLOT(toggleSlideShow()));
+        mToggleSlideShowAction = view->addAction(QStringLiteral("toggle_slideshow"), q, SLOT(toggleSlideShow()));
         q->updateSlideShowAction();
         connect(mSlideShow, &SlideShow::stateChanged, q, &MainWindow::updateSlideShowAction);
 
@@ -505,9 +504,9 @@ struct MainWindow::Private {
         view->addAction(KStandardAction::ConfigureToolbars, q, SLOT(configureToolbars()));
 
 #ifdef KF5Purpose_FOUND
-        mShareAction = new KToolBarPopupAction(QIcon::fromTheme("document-share"), i18nc("@action Share images", "Share"), q);
+        mShareAction = new KToolBarPopupAction(QIcon::fromTheme(QStringLiteral("document-share")), i18nc("@action Share images", "Share"), q);
         mShareAction->setPopupMode(QToolButton::InstantPopup);
-        actionCollection->addAction("share", mShareAction);
+        actionCollection->addAction(QStringLiteral("share"), mShareAction);
         mShareMenu = new Purpose::Menu(q);
         mShareAction->setMenu(mShareMenu);
 
@@ -589,7 +588,7 @@ struct MainWindow::Private {
 
         action = undoGroup->createRedoAction(actionCollection);
         action->setObjectName(KStandardAction::name(KStandardAction::Redo));
-        action->setIcon(QIcon::fromTheme("edit-redo"));
+        action->setIcon(QIcon::fromTheme(QStringLiteral("edit-redo")));
         action->setIconText(i18n("Redo"));
         actionCollection->setDefaultShortcuts(action, KStandardShortcut::redo());
 
@@ -597,7 +596,7 @@ struct MainWindow::Private {
 
         action = undoGroup->createUndoAction(actionCollection);
         action->setObjectName(KStandardAction::name(KStandardAction::Undo));
-        action->setIcon(QIcon::fromTheme("edit-undo"));
+        action->setIcon(QIcon::fromTheme(QStringLiteral("edit-undo")));
         action->setIconText(i18n("Undo"));
         actionCollection->setDefaultShortcuts(action, KStandardShortcut::undo());
         edit->addAction(action->objectName(), action);
@@ -625,28 +624,53 @@ struct MainWindow::Private {
 
         // Fill sidebar
         SideBarPage *page;
-        page = new SideBarPage(QIcon::fromTheme("folder"), i18n("Folders"));
-        page->setObjectName(QLatin1String("folders"));
+        page = new SideBarPage(QIcon::fromTheme(QStringLiteral("folder")), i18n("Folders"));
+        page->setObjectName(QStringLiteral("folders"));
         page->addWidget(folderViewItem->widget());
         page->layout()->setContentsMargins(0, 0, 0, 0);
         mSideBar->addPage(page);
 
-        page = new SideBarPage(QIcon::fromTheme("documentinfo"), i18n("Information"));
-        page->setObjectName(QLatin1String("information"));
-        page->addWidget(infoItem->widget());
+        page = new SideBarPage(QIcon::fromTheme(QStringLiteral("documentinfo")), i18n("Information"));
+        page->setObjectName(QStringLiteral("information"));
 #ifndef GWENVIEW_SEMANTICINFO_BACKEND_NONE
+        // If we have semantic info, we want to share the sidebar using a splitter,
+        // so the user can dynamically resize the two widgets.
         if (semanticInfoItem) {
+            auto splitter = new QSplitter;
+            splitter->setObjectName(QStringLiteral("information_splitter")); // This name is used to find it when loading previous sizes.
+            splitter->setOrientation(Qt::Vertical);
+            splitter->setHandleWidth(5);
+
+            splitter->addWidget(infoItem->widget());
+            splitter->setCollapsible(0, false);
+
+            // Cram the semantic info widget and a separator into a separate widget,
+            // so that they can be added to the splitter together (layouts can't be added directly).
+            // This will give the splitter a visible separator between the two widgets.
             auto separator = new QFrame;
             separator->setFrameShape(QFrame::HLine);
             separator->setLineWidth(1);
-            page->addWidget(separator);
-            page->addWidget(semanticInfoItem->widget());
+
+            auto container = new QWidget;
+            auto containerLayout = new QVBoxLayout(container);
+            containerLayout->setContentsMargins(0, 0, 0, 0);
+            containerLayout->addWidget(separator);
+            containerLayout->addWidget(semanticInfoItem->widget());
+
+            splitter->addWidget(container);
+            splitter->setCollapsible(1, false);
+
+            page->addWidget(splitter);
+        } else {
+            page->addWidget(infoItem->widget());
         }
+#else
+        page->addWidget(infoItem->widget());
 #endif
         mSideBar->addPage(page);
 
-        page = new SideBarPage(QIcon::fromTheme("document-edit"), i18n("Operations"));
-        page->setObjectName(QLatin1String("operations"));
+        page = new SideBarPage(QIcon::fromTheme(QStringLiteral("document-edit")), i18n("Operations"));
+        page->setObjectName(QStringLiteral("operations"));
         page->addWidget(imageOpsItem->widget());
         auto separator = new QFrame;
         separator->setFrameShape(QFrame::HLine);
@@ -773,10 +797,10 @@ struct MainWindow::Private {
         }
 
         KActionCollection *actionCollection = q->actionCollection();
-        actionCollection->action("file_save")->setEnabled(canSave && isModified);
-        actionCollection->action("file_save_as")->setEnabled(canSave);
-        actionCollection->action("file_print")->setEnabled(isRasterImage);
-        actionCollection->action("file_print_preview")->setEnabled(isRasterImage);
+        actionCollection->action(QStringLiteral("file_save"))->setEnabled(canSave && isModified);
+        actionCollection->action(QStringLiteral("file_save_as"))->setEnabled(canSave);
+        actionCollection->action(QStringLiteral("file_print"))->setEnabled(isRasterImage);
+        actionCollection->action(QStringLiteral("file_print_preview"))->setEnabled(isRasterImage);
 
 #ifdef KF5Purpose_FOUND
         if (url.isEmpty()) {
@@ -864,6 +888,30 @@ struct MainWindow::Private {
         }
     }
 
+    void loadInformationSplitterConfig()
+    {
+        const QList<int> sizes = GwenviewConfig::informationSplitterSizes();
+        if (!sizes.isEmpty()) {
+            // Find the splitter inside the sidebar by objectName.
+            auto informationSidebar = mSideBar->findChild<QSplitter *>(QStringLiteral("information_splitter"), Qt::FindChildrenRecursively);
+            if (informationSidebar) {
+                informationSidebar->setSizes(sizes);
+            } else {
+                qCWarning(GWENVIEW_APP_LOG) << "Could not find information splitter in sidebar when loading old position.";
+            }
+        }
+    }
+
+    void saveInformationSplitterConfig()
+    {
+        auto informationSidebar = mSideBar->findChild<QSplitter *>(QStringLiteral("information_splitter"), Qt::FindChildrenRecursively);
+        if (informationSidebar) {
+            GwenviewConfig::setInformationSplitterSizes(informationSidebar->sizes());
+        } else {
+            qCWarning(GWENVIEW_APP_LOG) << "Could not find information splitter in sidebar when saving new position.";
+        }
+    }
+
     void setScreenSaverEnabled(bool enabled)
     {
         // Always delete mNotificationRestrictions, it does not hurt
@@ -998,7 +1046,7 @@ MainWindow::MainWindow()
         new Mpris2Service(d->mSlideShow, d->mContextManager, d->mToggleSlideShowAction, d->mFullScreenAction, d->mGoToPreviousAction, d->mGoToNextAction, this);
 #endif
 
-    auto ratingMenu = static_cast<QMenu *>(guiFactory()->container("rating", this));
+    auto ratingMenu = static_cast<QMenu *>(guiFactory()->container(QStringLiteral("rating"), this));
     ratingMenu->setIcon(QIcon::fromTheme(QStringLiteral("rating-unrated")));
 #ifdef GWENVIEW_SEMANTICINFO_BACKEND_NONE
     if (ratingMenu) {
@@ -1706,17 +1754,29 @@ bool MainWindow::queryClose()
     KGuiItem no(i18n("Discard Changes"), "delete");
     QString msg =
         i18np("One image has been modified.", "%1 images have been modified.", list.size()) + '\n' + i18n("If you quit now, your changes will be lost.");
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    int answer = KMessageBox::warningTwoActionsCancel(this, msg, QString() /* caption */, yes, no);
+#else
     int answer = KMessageBox::warningYesNoCancel(this, msg, QString() /* caption */, yes, no);
+#endif
 
     switch (answer) {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    case KMessageBox::PrimaryAction:
+#else
     case KMessageBox::Yes:
+#endif
         d->mGvCore->saveAll();
         // We need to wait a bit because the DocumentFactory is notified about
         // saved documents through a queued connection.
         qApp->processEvents();
         return DocumentFactory::instance()->modifiedDocumentList().isEmpty();
 
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    case KMessageBox::SecondaryAction:
+#else
     case KMessageBox::No:
+#endif
         return true;
 
     default: // cancel
@@ -1780,6 +1840,7 @@ void MainWindow::loadConfig()
     d->mContextManager->loadConfig();
     d->mSideBar->loadConfig();
     d->loadSplitterConfig();
+    d->loadInformationSplitterConfig();
 }
 
 void MainWindow::saveConfig()
@@ -1789,6 +1850,7 @@ void MainWindow::saveConfig()
     d->mBrowseMainPage->saveConfig();
     d->mContextManager->saveConfig();
     d->saveSplitterConfig();
+    d->saveInformationSplitterConfig();
     GwenviewConfig::setFullScreenModeActive(isFullScreen());
     // Save the last used version when Gwenview closes so we know which settings/features the user
     // is aware of which is needed for migration. The version format is: two digits each for
