@@ -39,10 +39,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 namespace Gwenview
 {
 struct HudWidgetPrivate {
-    HudWidget *q;
-    QPropertyAnimation *mAnim;
-    QGraphicsWidget *mMainWidget;
-    HudButton *mCloseButton;
+    HudWidget *q = nullptr;
+    QPropertyAnimation *mAnim = nullptr;
+    QGraphicsWidget *mMainWidget = nullptr;
+    HudButton *mCloseButton = nullptr;
     bool mAutoDeleteOnFadeout;
 
     void fadeTo(qreal value)
@@ -77,7 +77,7 @@ HudWidget::~HudWidget()
 
 void HudWidget::init(QWidget *mainWidget, Options options)
 {
-    auto *proxy = new QGraphicsProxyWidget(this);
+    auto proxy = new QGraphicsProxyWidget(this);
     proxy->setWidget(mainWidget);
     init(proxy, options);
 }
@@ -88,7 +88,7 @@ void HudWidget::init(QGraphicsWidget *mainWidget, Options options)
         setProperty("opaque", QVariant(true));
     }
 
-    auto *layout = new QGraphicsLinearLayout(this);
+    auto layout = new QGraphicsLinearLayout(this);
     layout->setContentsMargins(4, 4, 4, 4);
     d->mMainWidget = mainWidget;
     if (d->mMainWidget) {
